\name{boat3d}
\alias{boat3d}
\title{ Draw boat glyphs for orientation data }
\description{
  Draws a stylized sailboat to represent an orientation.
}
\usage{
boat3d(orientation, x = 1:length(orientation), y = 0, 
       z = 0, scale = 0.25, col = 'red', add = FALSE, box = FALSE, axes = TRUE,
       graphics = c('djmrgl', 'rgl', 'scatterplot3d'), ...)
}
\arguments{
  \item{orientation}{ An \code{\link{orientation}} object to be shown. }
  \item{x, y, z}{ Coordinates where boats should be shown. }
  \item{scale}{ Size of boats }
  \item{col}{ Colour of boats }
  \item{add}{ Context in which to continue drawing, or \code{FALSE} to clear first.  }
  \item{box}{ Whether to draw a box around the plot }
  \item{axes}{ Whether to draw axes }
  \item{graphics}{ Which graphics package to use }
  \item{...}{ Additional graphics parameters; see Details below }
}
\details{
  For the identity orientation, the sailboats will be shown upright.
  Other orientations are shown as rotations of this glyph.
 
  The (x,y,z) coordinate appears in the middle of the sail, at the
  top of the gunwales of the boat.
  
  If either the \code{\link[djmrgl]{djmrgl}} or \code{\link[rgl]{rgl}} package is 
  installed, it will be used to draw solid faces on the boats which can be moved by the
  user.  If not, but the \code{\link[scatterplot3d]{scatterplot3d}} package is
  installed, it will be used to draw fixed wireframe boats.  This
  search order can be changed by modifying the \code{graphics} parameter.
  
  Additional graphics parameters may be passed.  If \code{\link[djmrgl]{djmrgl}}
  graphics is used, then these are passed to \code{\link[djmrgl]{par3d}} before
  the plotting is done; if \code{\link[scatterplot3d]{scatterplot3d}} is used, these
  are passed to the \code{\link[scatterplot3d]{scatterplot3d}} function (and ignored
  when adding to an existing plot).  Extra parameters are not passed to
  \code{\link[rgl]{rgl}}.
  
  To add to a \code{\link[scatterplot3d]{scatterplot3d}} plot, you must pass the 
  return value from the initial plot as the value of \code{add}.  See
  the \code{\link{orientlm}} function for an example.
}
\value{
  A \code{\link[djmrgl]{djmrgl}} handle for the graphics display, a current
  plot number for \code{\link[rgl]{rgl}}, or a \code{\link[scatterplot3d]{scatterplot3d}} 
  drawing context.  In any case, an attribute named \code{graphics} is added
  to indicate the drawing device type.
}
\author{ Duncan Murdoch }
\note{ Requires the \code{\link[djmrgl]{djmrgl}}, \code{\link[rgl]{rgl}} or 
\code{\link[scatterplot3d]{scatterplot3d}} package. }

\examples{
x <- eulerzyx(psi=c(0,pi/4,0,0), theta=c(0,0,pi/4,0), phi=c(0,0,0,pi/4))

# Need a 3D renderer; assume scatterplot3d, but others could be used

s <- boat3d(x, 0:3, axes = FALSE, graphics = 'scatterplot3d')
text(s$xyz.convert(0:3, rep(-0.5,4), rep(-0.5,4)), 
     label = c('Id','z','y','x'))
         
\dontrun{

# if the djmrgl package is loaded, this code will work
         
boat3d(x, 0:3, axes = FALSE)
axis3d('yz',at=0:3,labels=c('Id','z','y','x'))

# if the rgl package is loaded, this code will work

boat3d(x, 0:3, axes = FALSE, graphics = 'rgl')
rgl.bbox(xat=0:3,xlab=c('Id','z','y','x'),yat=1,zat=1,color='grey')  
}
}
\keyword{ hplot }% at least one, from doc/KEYWORDS
\keyword{ dynamic }% __ONLY ONE__ keyword per line

\eof
\name{coerce-methods}
\docType{methods}
\alias{coerce,matrix,orientation-method}
\alias{coerce,matrix,eulerzyx-method}
\alias{coerce,matrix,eulerzxz-method}
\alias{coerce,array,orientation-method}
\alias{coerce,orientation,rotvector-method}
\alias{coerce,orientation,eulerzyx-method}
\alias{coerce,orientation,quaternion-method}
\alias{coerce,orientation,skewvector-method}
\alias{coerce,orientation,skewmatrix-method}
\alias{coerce,orientation,eulerzxz-method}
\alias{coerce,rotvector,rotmatrix-method}
\alias{coerce,eulerzyx,rotmatrix-method}
\alias{coerce,quaternion,rotmatrix-method}
\alias{coerce,skewvector,quaternion-method}
\alias{coerce,skewvector,rotmatrix-method}
\alias{coerce,skewmatrix,skewvector-method}
\alias{coerce,skewmatrix,rotmatrix-method}
\alias{coerce,eulerzxz,rotmatrix-method}
\title{ Methods for Function coerce in Package `orientlib' }
\description{ Coercion methods are provided between all types of \code{orientation}
objects, and from matrices to the orientation classes.}
\keyword{methods}


\eof
\name{eulerzxz}
\alias{eulerzxz}
\alias{eulerzxz,orientation,missing,missing-method}
\title{ Create an orientation using Euler angles }
\description{
  Creates an \code{\link{eulerzxz-class}} object.
}
\usage{
eulerzxz(phi, theta, psi)
}
\arguments{
  \item{phi}{ Rotation about Z axis }
  \item{theta}{ Rotation about X axis }
  \item{psi}{ Further rotation about Z axis }
}
\details{
  The rotations are expressed in radians and applied in the order Z, X, Z.
  
  If \code{theta} and \code{psi} are missing, \code{phi} is taken to be an n x 3 matrix
  (or 3 element vector) holding all 3 Euler angles; alternatively, it may be an orientation object.
 
}
\value{
An \code{\link{eulerzxz-class}} object.
}
\author{ Duncan Murdoch }

\seealso{\code{\link{eulerzxz-class}}, \code{\link{eulerzyx-class}}, \code{\link{rotmatrix}}, \code{\link{rotvector}}, \code{\link{quaternion}},
\code{\link{skewvector}}, \code{\link{skewmatrix}}}
\examples{
x <- eulerzxz(c(1,0,0), c(0,1,0), c(0,0,1))
x
rotmatrix(x)
}
\keyword{array }% at least one, from doc/KEYWORDS
\keyword{algebra }% __ONLY ONE__ keyword per line

\eof
\name{eulerzyx}
\alias{eulerzyx}
\alias{eulerzyx,orientation,missing,missing-method}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Create an orientation using Euler angles }
\description{
  Creates an \code{\link{eulerzyx-class}} object.
}
\usage{
eulerzyx(psi, theta, phi)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{psi}{ Rotation about Z axis }
  \item{theta}{ Rotation about Y axis }
  \item{phi}{ Rotation about X axis }
}
\details{
  The rotations are expressed in radians and applied in the order Z, Y, X.
  
  If \code{theta} and \code{phi} are missing, \code{psi} is taken to be an n x 3 matrix
  (or 3 element vector) holding all 3 Euler angles; alternatively, any orientation object
  may be used.
}
\value{
An \code{\link{eulerzyx-class}} object.
}
\author{ Duncan Murdoch }

\seealso{\code{\link{eulerzyx-class}}, \code{\link{rotmatrix}}, \code{\link{rotvector}}, \code{\link{quaternion}},
\code{\link{skewvector}}, \code{\link{skewmatrix}}}
\examples{
x <- eulerzyx(c(1,0,0), c(0,1,0), c(0,0,1))
x
rotmatrix(x)
}
\keyword{array }% at least one, from doc/KEYWORDS
\keyword{algebra }% __ONLY ONE__ keyword per line

\eof
\name{index-methods}
\docType{methods}
\alias{[,rotmatrix-method}
\alias{[,rotvector-method} 
\alias{[,eulerzyx-method}
\alias{[,quaternion-method} 
\alias{[,skewvector-method}
\alias{[,skewmatrix-method}
\alias{[,eulerzxz-method}
\alias{[[,rotmatrix-method}
\alias{[[,rotvector-method}
\alias{[[,eulerzyx-method}
\alias{[[,quaternion-method}
\alias{[[,skewvector-method}
\alias{[[,skewmatrix-method}
\alias{[[,eulerzxz-method}
\alias{[[<-,rotmatrix-method}
\alias{[[<-,rotvector-method}
\alias{[[<-,eulerzyx-method}
\alias{[[<-,quaternion-method}
\alias{[[<-,skewvector-method}
\alias{[[<-,skewmatrix-method}
\alias{[[<-,eulerzxz-method}
\alias{[<-,rotmatrix-method}
\alias{[<-,rotvector-method}
\alias{[<-,eulerzyx-method}
\alias{[<-,quaternion-method}
\alias{[<-,skewvector-method}
\alias{[<-,skewmatrix-method}
\alias{[<-,eulerzxz-method}
\title{ Methods for indexing orientations }
\description{ Methods are defined for indexing all types of orientations. }
\details{Single bracket indexing (e.g. \code{x[1:3]}) creates a new
orientation object of the same class as the original by selecting the
appropriate entries.  Double bracket indexing (e.g. \code{x[[3]]}) extracts
the chosen data as a matrix or vector, depending on the class of the orientation. }

\keyword{methods}


\eof
\name{length-methods}
\docType{methods}
\alias{length,rotmatrix-method}
\alias{length,rotvector-method}
\alias{length,eulerzyx-method}
\alias{length,quaternion-method}
\alias{length,skewvector-method}
\alias{length,skewmatrix-method}
\alias{length,eulerzxz-method}
\title{ Length of orientation object }
\description{ The generic \code{length()} function has methods
for \code{orientations}; it counts the number of orientations in the
object.  }
\keyword{methods}


\eof
\name{matrix-classes}
\docType{class}
\alias{matrix-classes}
\alias{rotmatrix-class}
\alias{skewmatrix-class}
\title{Matrix orientation classes }
\description{ An orientation represented by 3 x 3 SO(3) matrices or 3 x 3 skew symmetric matrices }
\section{Objects from the Class}{
Objects can be created by calls of the form \code{\link{rotmatrix}(x)} 
or \code{\link{skewmatrix}(x)}.
The objects store the matrices in a 3 x 3 x n array.
}
\section{Slots}{
  \describe{
    \item{\code{x}:}{3 x 3 x n array holding the matrices. }
  }
}
\section{Extends}{
Class \code{"orientation"}, directly.
Class \code{"vector"}, by class "orientation".
}
\section{Methods}{
  \describe{
    \item{[, [<-}{Extract or assign to subvector }
    \item{[[, [[<-}{Extract or assign to an entry }
    \item{length}{The length of the \code{orientation} vector }
    \item{coerce}{Coerce methods are defined to convert all \code{\link{orientation}} descendants
    from one to another, and to coerce an appropriately shaped matrix or array to a \code{rotmatrix}}
  }
}
\author{ Duncan Murdoch }

\seealso{\code{\link{orientation-class}}, \code{\link{vector-classes}}, \code{\link{rotmatrix}}, 
\code{\link{skewmatrix}}}

\examples{
x <- rotmatrix(matrix(c(1,0,0, 0,1,0, 0,0,1), 3, 3))
x
skewmatrix(x)
}
\keyword{classes}

\eof
\name{matrix-methods}
\docType{methods}
\alias{\%*\%,orientation,orientation-method}
\alias{t,orientation-method}
\alias{^,orientation,numeric-method}
\title{ Methods for matrix operations in `orientlib' }
\description{ Methods are defined for matrix multiplication \code{\%*\%}
transposition \code{t()}, and real powers \code{^}.  These operate on the orientations
term by term.}
\keyword{methods}


\eof
\name{mean-methods}
\docType{methods}
\title{Methods for calculating the mean}
\alias{mean-methods}
\alias{mean,ANY-method}
\alias{mean,orientation-method}
\description{The mean function. }
\section{Methods}{\describe{

\item{x = "ANY"}{ the standard mean function }

\item{x = "orientation"}{ find the nearest SO(3) matrix to the mean \code{\link{rotmatrix-class}}
representation of the orientations }
}}
\keyword{methods}

\eof
\name{nearest}
\alias{nearest.SO3}
\alias{nearest.orthog}
\title{ Find nearest SO(3) or orthogonal matrix. }
\description{
Converts arbitrary 3 x 3 matrices 
into the nearest SO(3) or orthogonal matrix.
}
\usage{
nearest.SO3(x)
nearest.orthog(x)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ 3 x 3 matrices stored in a 3 x 3 x n array) }
}
\details{
Uses Stephens' (1979) algorithm to find the nearest (in entry-wise Euclidean sense)
SO(3) or orthogonal matrix to a given matrix.
} 
\value{
\code{nearest.SO3} produces an \code{\link{orientation-class}} object holding the closest orientations.

\code{nearest.orthog} produces a 3 x 3 x n array of orthogonal matrices.
}
\references{ Stephens (1979).  Vector correlation.  {\em Biometrika} 66, 41-48.}
\author{ Duncan Murdoch }

\seealso{\code{\link{orientation-class}}}
\examples{
x <- matrix(rnorm(9), 3,3)
nearest.orthog(x)
nearest.SO3(x)
x <- -x
nearest.orthog(x)
nearest.SO3(x)
}
\keyword{array }% at least one, from doc/KEYWORDS
\keyword{algebra }% __ONLY ONE__ keyword per line

\eof
\name{orientation-class}
\docType{class}
\alias{orientation-class}
\alias{orientation}
\title{Class "orientation" }
\description{  Abstract class for vectors of various representations of SO(3) (orientation)
objects.}
\section{Objects from the Class}{A virtual Class: No objects may be created from it.}

\section{Methods}{
  \describe{
    \item{coerce}{Methods are defined to coerce \code{orientation} objects to any
    concrete descendant class.}
    \item{\code{\%*\%}}{Matrix multiplication acts on \code{orientation} objects 
    	component by component, producing compositions of the rotations.}
    \item{\code{^}}{An orientation is raised to a power by multiplying its component rotation angles
     	by that power.}
    \item{t}{The transpose of an \code{orientation} object is its 
    	component by component inverse.}
    \item{mean}{The mean of an \code{orientation} object is the nearest SO(3) matrix to 
    the element-by-element mean of its 3 x 3 rotation matrix representation.}
    \item{weighted.mean}{The weighted mean, defined analogously to the \code{mean}.}
  }
}
\author{ Duncan Murdoch }
\seealso{ \code{\link{matrix-classes}}, \code{\link{vector-classes}}}

\examples{
x <- rotmatrix(diag(3))
x
rotvector(x)
eulerzyx(x)
eulerzxz(x)
quaternion(x)
}
\keyword{classes}

\eof
\name{orientlib}
\alias{orientlib}
\title{ Orientation Library }
\description{
  Representations, conversions and display of orientation data.
}

\details{
  This package contains methods for working with orientation data, i.e.
  data from SO(3).  The basic abstract class is the \code{\link{orientation}};
  there are several concrete classes (\code{\link{rotmatrix}}, 
  \code{\link{rotvector}}, \code{\link{eulerzyx}}, \code{\link{eulerzxz}}, 
  \code{\link{quaternion}}, \code{\link{skewmatrix}} and \code{\link{skewvector}}) 
  storing different 
  representations of orientations.

  Methods are defined to get the length of a vector of orientations, as well
  as to extract and replace elements, and to multiply orientations and raise 
  them to real powers.

  There are also utility functions \code{\link{rotation.distance}},
  \code{\link{rotation.angle}}, \code{\link{nearest.orthog}}, 
  \code{\link{nearest.SO3}}.
  
  There is a plotting method \code{\link{boat3d}} to display orientation data
  in a 3D plot, and a linear modelling function \code{\link{orientlm}}.
}

\section{Release History}{
\itemize{
\item{Versions 0.3, 0.4, 0.5}{
\itemize{

\item{-}{Changes for CRAN compliance.}
}}

\item{Version 0.2}{
\itemize{

\item{-}{Added \code{mean} and \code{weighted.mean}.}

\item{-}{Made \code{orientation} descend from \code{vector}.}

\item{-}{Added \code{[[} methods.}

\item{-}{Changed default look of boats.}

\item{-}{Made \code{rotmatrix} etc. into conversion functions between
orientation types.}

\item{-}{Added \code{eulerzxz} class.}

\item{-}{Added various parameters to \code{boat3d}.}

\item{-}{Added \code{\link{orientlm}} regression function plus transpose \code{t()} method.}

\item{-}{Added \code{\link[rgl]{rgl}} and \code{\link[scatterplot3d]{scatterplot3d}} support to \code{\link{boat3d}} function.}

\item{-}{Added \code{\link{skewmatrix}}.}
}}

\item{Version 0.1}{
\itemize{
\item{-}{First release.}
}}
}
}

\author{ Duncan Murdoch }
\note{ Plots require one of the \code{\link[djmrgl]{djmrgl}}, \code{\link[rgl]{rgl}}, 
or \code{\link[scatterplot3d]{scatterplot3d}} libraries. }


\keyword{ hplot }% at least one, from doc/KEYWORDS
\keyword{ dynamic }% __ONLY ONE__ keyword per line
\keyword{ array }

\eof
\name{orientlm}
\alias{orientlm}
\title{ Linear models for orientation data }
\description{
  Regression models for matched pairs of orientations.
}
\usage{
orientlm(observed, leftformula, trueorient = rotmatrix(diag(3)), 
         rightformula, data = list(), subset, weights, na.action, 
         iterations = 5)
}
\arguments{
  \item{observed}{ Observed orientations }
  \item{leftformula}{ Formula for ``left'' model (see below) }
  \item{trueorient}{ ``True'' orientation (see below) }
  \item{rightformula}{ Formula for ``right'' model (see below) }
  \item{data}{ Optional data frame for predictors in linear model }
  \item{subset}{ Optional logical vector indicating subset of data }
  \item{weights}{ Optional weights }
  \item{na.action}{ Optional NA function for predictors }
  \item{iterations}{ How many iterations to use.  Ignored unless both 
  	\code{leftformula} and \code{rightformula} are specified.}
}
\details{
The Prentice (1989) model for matched pairs of orientations was

\deqn{E(V_i) = k A_1^t U_i A_2}{E(Vi) = k t(A1) \%*\% Ui \%*\% A2}

where \eqn{V_i}{Vi} is the observed orientation, \eqn{A_1}{A1} and \eqn{A_2}{A2} are orientation matrices,
and \eqn{U_i}{Ui} is the ``true'' orientation, and \eqn{k} is a constant.  It was assumed that
errors were symmetrically distributed about the identity matrix.

This function generalizes this model, allowing \eqn{A_1}{A1} and \eqn{A_2}{A2} to depend on
regressor variables through \code{leftformula} and \code{rightformula} respectively.  
These formulas should include the predictor variables (right hand side) only, e.g. use
\code{~ x + y + z} rather than \code{response ~ x + y + z}.  Specify the response using
the \code{observed} argument.  If 
both formulas are \code{~ 1}, i.e. intercepts only, then Prentice's original model is 
recovered.  More general models are fit by coordinatewise linear regression in the \code{\link{rotmatrix}}
representation of the orientation, with fitted values projected onto SO(3) using the 
\code{\link{nearest.SO3}} function.

When both left and right models are given, Prentice's iterative approach is used with
a fixed number of iterations.  Note that
Shin (1999) found that Prentice's scheme sometimes fails to find the 
global minimum; this function presumably suffers from the same failing.
}
\value{
  Returns a list containing the following components:
  \item{leftfit }{Result of \code{\link[base]{lm}} call based on \code{leftformula}}
  \item{rightfit }{Result of \code{\link[base]{lm}} call based on \code{rightformula}}
  \item{A1 }{Fitted values of \eqn{A_1}{A1} for each observation}
  \item{A2 }{Fitted values of \eqn{A_2}{A2} for each observation}
  \item{predict}{Fitted values of \eqn{A_1^t U_i A_2}{t(A1) \%*\% Ui \%*\% A2} for each observation}
}
\references{ 
Prentice, M.J. (1989).  Spherical regression on matched pairs of orientation statistics.
JRSS B 51, 241-248.

Shin, H.S.H. (1999).  Experimental Design for Orientation Models.  PhD thesis, Queen's University.
}
\author{ Duncan Murdoch }
\examples{
x <- rep(1:10,10)
y <- rep(1:10,each=10)
A1 <- skewvector(cbind(x/10,y/10,rep(0,100)))
A2 <- skewvector(c(1,1,1))
trueorientation <- skewvector(matrix(rnorm(300),100))
noise <- skewvector(matrix(rnorm(300)/10,100))
obs <- t(A1) \%*\% trueorientation \%*\% A2 \%*\% noise

fit <- orientlm(obs, ~ x + y, trueorientation, ~ 1)

context <- boat3d(A1, x, z=y, col = 'green', graphics='scatterplot3d')
boat3d(fit$A1, x, z=y, add=context)
}
\keyword{ regression }% at least one, from doc/KEYWORDS


\eof
\name{quaternion}
\alias{quaternion}
\alias{quaternion,orientation-method}
\title{ Create an orientation using quaternions }
\description{
  Creates a \code{\link{quaternion-class}} object.
}
\usage{
quaternion(m)
}
\arguments{
  \item{m}{ n x 4 matrix or 4 element vector containing a unit quaternion, or an orientation object }
}
\details{
The rows of \code{m} are 4 element unit vectors interpreted as 
follows:  the first 3 \code{(x,y,z)} define the axis of rotation,
and the last element gives the cosine of half the angle of
rotation in a counter-clockwise direction when looking down the 
axis towards the origin.
}
\value{
A \code{\link{quaternion-class}} object.
}
\author{ Duncan Murdoch }

\seealso{\code{\link{quaternion-class}}, \code{\link{rotmatrix}}, \code{\link{rotvector}}, \code{\link{eulerzyx}},
         \code{\link{eulerzxz}}, \code{\link{skewvector}}, \code{\link{skewmatrix}}}
\examples{
x <- quaternion(c(1,0,0,0))
x
rotmatrix(x)
}
\keyword{array }% at least one, from doc/KEYWORDS
\keyword{algebra }% __ONLY ONE__ keyword per line

\eof
\name{rotation.distance}
\alias{rotation.distance}
\alias{rotation.angle}
\title{ Rotation angle or distance }
\description{
Calculates the angle (in radians) of the rotation taking one orientation to
another.
}
\usage{
rotation.angle(x)
rotation.distance(x, y)
}
\arguments{
  \item{x,y}{ Two orientation objects }
}
\value{
\code{rotation.distance} returns a vector of length \code{max(length(x), length(y))} 
containing the
angle of the rotation taking corresponding elements of \code{x} to \code{y} (with the
usual recycling rules if they are different lengths). 

\code{rotation.angle} is equivalent to calculating the \code{rotation.distance} to the
identity matrix.

}
\details{ If \code{y} is missing in a call to \code{rotation.distance}, 
it is treated as the identity, i.e.
\code{\link{rotation.angle}(x)} is calculated.}

\author{ Duncan Murdoch } 

\seealso{ \code{\link{orientation-class}}, \code{\link{rotation.angle}}}
\examples{
rotation.angle(eulerzyx(1,0,0))
rotation.distance(eulerzyx(1,0,0), eulerzyx(0,1,0))

}
\keyword{array }% at least one, from doc/KEYWORDS
\keyword{algebra }% __ONLY ONE__ keyword per line

\eof
\name{rotmatrix}
\alias{rotmatrix}
\alias{rotmatrix,orientation-method}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Create an orientation using Euler angles }
\description{
    Creates a \code{\link{rotmatrix-class}} object.
}
\usage{
rotmatrix(a)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{a}{ A 3 x 3 matrix or 3 x 3 x n array of matrices or an orientation object. }
}
\value{
A \code{\link{rotmatrix-class}} object.
}
\author{ Duncan Murdoch }

\seealso{\code{\link{rotmatrix-class}},  \code{\link{rotvector}}, \code{\link{eulerzyx}}, 
\code{\link{eulerzxz}}, \code{\link{quaternion}}, \code{\link{skewvector}}, \code{\link{skewmatrix}}}
\examples{
x <- rotmatrix(matrix(c(1,0,0, 0,1,0, 0,0,1), 3, 3))
x
}
\keyword{array }% at least one, from doc/KEYWORDS
\keyword{algebra }% __ONLY ONE__ keyword per line

\eof
\name{rotvector}
\alias{rotvector}
\alias{rotvector,orientation-method}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Create an orientation using vectorized 3x3 matrices }
\description{
   Creates a \code{\link{rotvector-class}} object.
}
\usage{
rotvector(m)
}
\arguments{
  \item{m}{ n x 9 matrix or 9 element vector whose rows are vectorized 3x3 matrices, or an orientation object.}
}
\details{
Converts a matrix whose rows are vectorized 3x3 matrices (in column-major form)
into an \code{\link{rotvector-class}} object.
}
\value{
A \code{\link{rotvector-class}} object.
}
\author{ Duncan Murdoch }
\seealso{\code{\link{rotvector-class}}, \code{\link{rotmatrix}},  \code{\link{eulerzyx}},
\code{\link{eulerzxz}}, \code{\link{quaternion}}, \code{\link{skewvector}}, \code{\link{skewmatrix}}}
\examples{
x <- rotvector(c(0,1,0,-1,0,0,0,0,1))
x
rotmatrix(x)
}
\keyword{array }% at least one, from doc/KEYWORDS
\keyword{algebra }% __ONLY ONE__ keyword per line

\eof
\name{skewmatrix}
\alias{skewmatrix}
\alias{skewmatrix,orientation-method}
\title{ Create an orientation using the entries in a skew-symmetric matrix representation }
\description{
  Creates a \code{\link{skewmatrix-class}} object.
}
\usage{
skewmatrix(a)
}
\arguments{
  \item{a}{ 3 x 3 x n array or 3 x 3 matrix containing the entries of a skew-symmetric matrix,
  	    or an orientation object.}
}
\details{
The entries \code{a[,,i]} are 3 x 3 skew-symmetric matrices.  
The matrix exponential of these give SO(3) matrices.

}
\value{
A \code{\link{skewmatrix-class}} object.
}
\author{ Duncan Murdoch }

\seealso{\code{\link{skewvector-class}}, \code{\link{skewvector}}, \code{\link{rotmatrix}}, \code{\link{rotvector}}, \code{\link{eulerzyx}},
		 \code{\link{eulerzxz}}, \code{\link{quaternion}}}
\examples{
x <- skewmatrix(matrix(c(0,1,2,-1,0,3,-2,-3,0),3,3))
x
rotmatrix(x)
skewvector(x)
rotation.angle(x)
}
\keyword{array }% at least one, from doc/KEYWORDS
\keyword{algebra }% __ONLY ONE__ keyword per line

\eof
\name{skewvector}
\alias{skewvector}
\alias{skewvector,orientation-method}
\title{ Create an orientation using the entries in a skew-symmetric matrix representation }
\description{
  Creates a \code{\link{skewvector-class}} object.
}
\usage{
skewvector(m)
}
\arguments{
  \item{m}{ n x 3 matrix or 3 element vector containing a the entries of a skew-symmetric matrix,
  	    or an orientation object.}
}
\details{
The rows of \code{m} are 3 element vectors (x,y,z) interpreted as 
follows:  the matrix exponential of the matrix \code{((0, -z, y), (z, 0, -x), (-y, x, 0))}
is the SO(3) matrix.

}
\value{
A \code{\link{skewvector-class}} object.
}
\author{ Duncan Murdoch }

\seealso{\code{\link{skewvector-class}}, \code{\link{skewmatrix}}, \code{\link{rotmatrix}}, \code{\link{rotvector}}, \code{\link{eulerzyx}},
		 \code{\link{eulerzxz}}, \code{\link{quaternion}}}
\examples{
x <- skewvector(c(1,0,0))
x
rotmatrix(x)
rotation.angle(x)
}
\keyword{array }% at least one, from doc/KEYWORDS
\keyword{algebra }% __ONLY ONE__ keyword per line

\eof
\name{vector-classes}
\docType{class}
\alias{eulerzyx-class}
\alias{eulerzxz-class}
\alias{rotvector-class}
\alias{quaternion-class}
\alias{skewvector-class}
\alias{vector-classes}
\title{Orientation classes }
\description{ An vector of orientations, each represented by a vector of numbers.
Each of these types stores orientations as rows of a matrix in slot \code{x}.

The \code{eulerzyx} class uses 3 Euler angles in the roll-pitch-yaw scheme
(rotation about Z axis, then Y axis, then X axis).

The \code{eulerzxz} class uses 3 Euler angles in the X system scheme
(rotation about Z axis, then X axis, then Z axis again).

The \code{rotvector} class uses the 9 components of a 3 x 3 rotation matrix, stored
in column-major order.

The \code{quaternion} class uses the 4 components of a unit quaternion.

The \code{skewvector} class uses the 3 non-zero components of a skew-symmetric matrix,
where \code{(x,y,z)} stores the matrix  \code{((0, -z, y), (z, 0, -x), (-y, x, 0))}.

}
\section{Objects from the Class}{
Objects of each class can be created by calls to the corresponding constructor
functions:  \code{\link{eulerzyx}}, \code{\link{eulerzxz}}, \code{\link{rotvector}},
\code{\link{quaternion}}, \code{\link{skewmatrix}} and \code{\link{skewvector}}.

}
\section{Slots}{
  \describe{
    \item{\code{x}:}{An n x m \code{matrix} object holding the vector representations, where
    m is 3, 4, or 9. }
  }
}
\section{Extends}{
Class \code{"orientation"}, directly.
Class \code{"vector"}, by class "orientation".
}
\section{Methods}{
  \describe{
    \item{[, [<-}{Extract or assign to subvector }
    \item{[[, [[<-}{Extract or assign to an entry }
    \item{length}{The length of the \code{orientation} vector }
    \item{coerce}{Coerce methods are defined to convert all \code{\link{orientation}} descendants
    from one to another, and to coerce an appropriately shaped matrix or array to a \code{rotmatrix}}
  }
}
\author{ Duncan Murdoch }

\seealso{Constructor and coercion functions \code{\link{rotmatrix}}, \code{\link{eulerzyx}}, \code{\link{eulerzxz}}, \code{\link{rotvector}},
\code{\link{quaternion}}, and \code{\link{skewvector}}. 

Classes \code{\link{matrix-classes}}, \code{\link{orientation-class}}.
}

\examples{
x <- eulerzyx(0,pi/4,0)
x
eulerzxz(x)
rotmatrix(x)
rotvector(x)
quaternion(x)
skewvector(x)
}
\keyword{classes}

\eof
\name{weighted.mean-methods}
\docType{methods}
\title{ Weighted mean function }
\alias{weighted.mean-methods}
\alias{weighted.mean,ANY,ANY,ANY-method}
\alias{weighted.mean,orientation,numeric,missing-method}
\description{The weighted mean function. }

\section{Methods}{\describe{

\item{x = "ANY", w = "ANY", na.rm = "ANY"}{ standard weighted mean function }

\item{x = "orientation", w = "numeric", na.rm = "missing"}{ weighted mean for orientations}
}}

\details{
 The weighted mean for orientations is the nearest SO(3) matrix to the entrywise weighted mean
 of the \code{\link{rotmatrix-class}} matrices.
}
\keyword{methods}

\eof
